@@ -5,6 +5,8 @@ import shlex
 import shutil
 import subprocess as sp
 from pathlib import Path
+import string
+import re
 
 import numpy as np
 import pandas as pd
@@ -146,7 +148,13 @@ class VDataAutodoc:
         makefile = self.target_dir / "Makefile"
         return conf.exists() and makefile.exists()
 
-    def dump_data(self, skip_tabs=(), drop_columns=(), rename_columns=(), order_columns=("column",)):
+    def dump_data(
+        self,
+        skip_tabs=(),
+        drop_columns=(),
+        rename_columns=(),
+        order_columns=("column",),
+    ):
         # =====================================================================
         # index.rst call master file `input_data.rst`
         # =====================================================================
@@ -185,7 +193,11 @@ class VDataAutodoc:
             filename = tabdir / f"{tab}.rst"
             if not filename.exists():
                 with open(filename, "w") as fh:
-                    fh.write(_write(f"Please edit ``{filename}`` to provide adequate description"))
+                    fh.write(
+                        _write(
+                            f"Please edit ``{filename}`` to provide adequate description"
+                        )
+                    )
             # -----------------------------------------------------------------
             # create private tab description file `source/tabs/.<tab>.rst`
             _filename = tabdir / f".{tab}.rst"
@@ -223,7 +235,7 @@ class VDataAutodoc:
                     df["set"] = pd.Series(uniq)
                     df["set"] = df.set.fillna("")
                 if mandatory:
-                    df["mandatory"] = pd.Series(mandatory)                     
+                    df["mandatory"] = pd.Series(mandatory)
                     df["mandatory"] = df.mandatory.fillna("")
                 if "type" in df.columns:
                     df["type"] = df["type"].replace(
@@ -250,7 +262,9 @@ class VDataAutodoc:
                     df = df.drop(columns=_drop_columns)
                 # -------------------------------------------------------------
                 # rename columns
-                _rename_columns = {prev: new for prev, new in rename_columns.items() if prev in df}
+                _rename_columns = {
+                    prev: new for prev, new in rename_columns.items() if prev in df
+                }
                 if _rename_columns:
                     df = df.rename(columns=_rename_columns)
                 # -------------------------------------------------------------
@@ -261,10 +275,147 @@ class VDataAutodoc:
                 )
                 fh.write(_write(table))
                 if _uniq:
-                    fh.write(_write("the following sets of columns combination need to be **unique**:"))
+                    fh.write(
+                        _write(
+                            "the following sets of columns combination need to be **unique**:"
+                        )
+                    )
                 for uniq, cols in _uniq.items():
                     columns = ", ".join([f"``{c}``" for c in cols])
-                    fh.write(_write(f"  * ``{uniq}``: {columns}")) 
+                    fh.write(_write(f"  * ``{uniq}``: {columns}"))
+
+
+# =============================================================================
+# dumping XLSX template
+# =============================================================================
+FMTS = {
+    "default": {
+        "bold": True,
+        "font_color": "#3A81CC",
+        "align": "center",
+        "valign": "vcenter",
+        "border": 1,
+        "bg_color": "#eeeeec",
+    },
+    "mandatory": {"bg_color": "#fcaf3e", "color": "black"},
+    "padded": {"bg_color": "#8ae234", "color": "black"},
+    "units": {"bg_color": "#729fcf", "color": "black"},
+}
+
+
+def fmt_dict(attributes=()):
+    fmt = FMTS["default"].copy()
+    for attr in attributes:
+        _d = FMTS[attr].copy()
+        fmt.update(_d)
+    return fmt
+
+
+def dump_xlsx_template(schemas, output, tabs=None, excluded_tabs=None):
+    """creates a blank XSLX spreadsheet based on provided schema"""
+    # -------------------------------------------------------------------------
+    alphabet = string.ascii_uppercase  # "ABC..."
+    # -------------------------------------------------------------------------
+    # read shema(s)
+    data = IVData()
+    data.read_schema(*schemas)
+    tabs = list(tabs)
+    for tabname, schema in data._schemas.items():
+        for referencing_col, (
+            referenced_tab,
+            referenced_col,
+        ) in schema.xcalling.items():
+            if referenced_tab not in tabs:
+                logging.warning(f"add referenced {referenced_tab}")
+                tabs.append(referenced_tab)
+    # -------------------------------------------------------------------------
+    # eventually filter with tabs wishlist
+    if tabs:
+        data._schemas = {k: v for k, v in data._schemas.items() if k in tabs}
+    if excluded_tabs:
+        data._schemas = {
+            k: v for k, v in data._schemas.items() if k not in excluded_tabs
+        }
+    # -------------------------------------------------------------------------
+    # automatically integrate referenced tabs
+    # -------------------------------------------------------------------------
+    # get columns and attributes
+    cols = data.dump_template()
+    with pd.ExcelWriter(output) as writer:
+        workbook = writer.book
+        # prepare formats
+        default_format = workbook.add_format(fmt_dict())
+        mandatory_format = workbook.add_format(fmt_dict(["mandatory"]))
+        padded_format = workbook.add_format(fmt_dict(["padded"]))
+        units_format = workbook.add_format(fmt_dict(["units"]))
+        for tabname, data in cols.items():
+            df = data["df"]
+            colspecs = data["schema"]
+            required = data["required"]
+            xcallings = data["xcalling"]
+            df.to_excel(
+                writer, sheet_name=tabname, startrow=1, header=False, index=False
+            )
+            worksheet = workbook.sheetnames[tabname]
+            # -----------------------------------------------------------------
+            # format header
+            # worksheet.set_row(0, height=None, cell_format=mandatory_format)
+            ws_has_units = {cs.get("units") for _, cs in colspecs.items()} > {None}
+            for i, colname in enumerate(df.columns):
+                is_mandatory = colname in required
+                pattern = colspecs[colname]["items"].get("pattern")
+                if pattern and not re.match(pattern, ""):
+                    is_mandatory = True
+                default = colspecs[colname]["items"].get("default")
+                is_padded = False
+                if default == "_pad_":
+                    is_mandatory = False
+                    is_padded = True
+                xcalling = xcallings.get(colname)
+                if is_mandatory or xcalling:
+                    fmt = mandatory_format
+                elif is_padded:
+                    fmt = padded_format
+                else:
+                    fmt = default_format
+                worksheet.write_string(0, i, colname, cell_format=fmt)
+                cell_header = "{col}{row}".format(col=alphabet[i], row=1)
+                # -------------------------------------------------------------
+                # process comments
+                types = set((colspecs[colname]["items"].get("type"),))
+                for typ in colspecs[colname]["items"].get("anyOf", []):
+                    types.add(typ["type"])
+                types.discard(None)
+                types_str = ", ".join(types)
+                comment = f"Type(s): {types_str}"
+                if colspecs[colname]["uniqueItems"]:
+                    comment += f"\nMust be Unique"
+                if pattern:
+                    comment += f"\nPattern: {pattern}"
+                if xcalling:
+                    comment += f"\ncross-ref: {xcalling[0]}/{xcalling[1]}"
+                if default is not None:
+                    if isinstance(default, str):
+                        comment += f'\ndefault: "{default}"'
+                    else:
+                        comment += f"\ndefault: {default}"
+                worksheet.write_comment(
+                    cell_header,
+                    comment,
+                    {
+                        "author": "numeric-GmbH",
+                        "color": "#ad7fa8",
+                        "visible": False,
+                    },
+                )
+            if ws_has_units:
+                worksheet.set_row(1, height=None, cell_format=units_format)
+                worksheet.freeze_panes(2, 1)
+            else:
+                worksheet.freeze_panes(1, 1)
+            # -----------------------------------------------------------------
+            # autofit
+    return output
 
 
 if __name__ == "__main__":
