@@ -12,11 +12,13 @@ import argparse
 import os
 import pprint
 import sys
+import string
 
 import pandas as pd
 
 from gridsource import Data, IOData, ValidData, __version__
 from gridsource.io import DEFAULT_EXCEL_ENGINE
+from gridsource.autodoc import dump_xlsx_template
 
 
 def version(args=None):
@@ -72,21 +74,17 @@ def export(args):
     return 0
 
 
-def dump_xlsx_template(args):
+def cli_dump_xlsx_template(args):
     """creates a blank XSLX spreadsheet based on provided schema"""
-    schema = args.schema
+    schemas = args.schemas
     output = args.output
     engine = args.engine
-    schema_dir, schema_fname = os.path.split(schema)
-    schema_fname, _ = os.path.splitext(schema_fname)
-    data = Data()
-    data.read_schema(args.schema)
-    breakpoint()
-    cols = data.dump_template()
-    with pd.ExcelWriter(output) as writer:
-        for tabname, df in cols.items():
-            df.to_excel(writer, sheet_name=tabname, index=False)
-    return output
+    tabs = args.tabs
+    excluded_tabs = args.excluded_tabs
+    output = dump_xlsx_template(
+        output=output, tabs=tabs, excluded_tabs=excluded_tabs, schemas=schemas
+    )
+    print(f"created {output}")
 
 
 def parse_args(args):
@@ -138,7 +136,9 @@ def parse_args(args):
     parser_dumper = subparsers.add_parser(
         "dump-template", help="dump template based on provided schema"
     )
-    parser_dumper.add_argument("schema", type=str, help="path to schema file")
+    parser_dumper.add_argument(
+        "schemas", type=str, metavar="S", nargs="+", help="path to schema file(s)"
+    )
     parser_dumper.add_argument(
         "-o",
         "--output",
@@ -147,14 +147,31 @@ def parse_args(args):
         help="output filepath",
     )
     parser_dumper.add_argument(
-        "-e",
         "--engine",
         type=str,
         default="xlrd",
         choices=("xlrd", "openpyxl"),
         help="pandas XLSX reader engine",
     )
-    parser_dumper.set_defaults(process=dump_xlsx_template)
+    parser_dumper.add_argument(
+        "-t",
+        "--tabs",
+        metavar="T",
+        nargs="+",
+        default=None,
+        type=str,
+        help="tabs whishlist",
+    )
+    parser_dumper.add_argument(
+        "-e",
+        "--excluded-tabs",
+        metavar="X",
+        nargs="+",
+        default=None,
+        type=str,
+        help="tabs blacklist",
+    )
+    parser_dumper.set_defaults(process=cli_dump_xlsx_template)
 
     # ========================================================================
     # return default func
